---
name: "\U0001F4ACQuestion"
about: Ask questions.

---

**Describe your question with as much detail as possible**
A clear and concise question that doesn't require too much conversation. Need more help? [Find me on Gitter](https://gitter.im/wswebcreation/multiple-cucumber-html-reporter-plugin)


**If it's about a specific piece of code, try and include some of it to support your question.**
[...]


**Environment (please complete the following information):**
 - multiple-cucumber-html-reporter: [e.g. 1.10.0]
 - Node.js version: [e.g. 8.9.1]
 - NPM version: [e.g. 5.8.0]
 - Platform name and version: [e.g. Windows 10]
 - Cucucmber version: [e.g. 4.2.0]


**Additional context**
Add any other context about the problem here.
